;*****************************************************************************
;				NICST TOOL
;
;  RC5 Part 1 graphs dn vs integration time.
;
;  Output:
;  1) postscript file containing graphs.
;  
;  v1.0 - 04/21/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_int_time_plot, infile

close,/all

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

restore,'general.TEB.2.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'

;*****************************************************************************
;  Some definitions.
;*****************************************************************************

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)
HAM=['HAM A','HAM B']
SS=[' SS1',' SS2']
DET=['DET 1','DET 2','DET 3','DET 4','DET 5','DET 6','DET 7','DET 8','DET 9', $
     'DET 10','DET 11','DET 12','DET 13','DET 14','DET 15','DET 16','DET 17', $
     'DET 18','DET 19','DET 20','DET 21','DET 22','DET 23','DET 24','DET 25', $
     'DET 26','DET 27','DET 28','DET 29','DET 31','DET 32']
time_int=['VisNIR M','VisNIR I','SMWIR M','SMWIR I','LWIR M','LWIR I']

default=[15*2.2,10*2.2,35*2.2,35*2.2,36*2.2,36*2.2,36*2.2,36*2.2]

;*****************************************************************************
;  Integration Time.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.int_time.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,1]
!p.position=0

title='Integration Time vs Collect'
plot,D[0:ncollects+1],(15-(inttime[1,1,0,0:ncollects-1]-2),xtit='Collect',ytit='Integration Time (Ticks)', $
  yrange=[min(inttime[*,*,0,*]),max(inttime[*,*,0,*])],charsize=1.2,charthick=5,thick=3,/nodata

oplot,D[0:ncollects-1]+1,(35-(inttime[0,0,0,0:ncollects-1]-2),symsize=1,color=lcol[0],psym=symbol[0],thick=3
oplot,D[0:ncollects-1]+1,(35-(inttime[0,0,0,0:ncollects-1]-2),symsize=1,color=lcol[0],thick=3

oplot,D[0:ncollects-1]+1,(15-(inttime[0,1,0,0:ncollects-1]-2),symsize=1,color=lcol[1],psym=symbol[1],thick=3
oplot,D[0:ncollects-1]+1,(15-(inttime[0,1,0,0:ncollects-1]-2),symsize=1,color=lcol[1],thick=3

oplot,D[0:ncollects-1]+1,(35-(inttime[1,0,0,0:ncollects-1]-2),symsize=1,color=lcol[2],psym=symbol[2],thick=3
oplot,D[0:ncollects-1]+1,(35-(inttime[1,0,0,0:ncollects-1]-2),symsize=1,color=lcol[2],thick=3

oplot,D[0:ncollects-1]+1,(15-(inttime[1,1,0,0:ncollects-1]-2),symsize=1,color=lcol[3],psym=symbol[3],thick=3
oplot,D[0:ncollects-1]+1,(15-(inttime[1,1,0,0:ncollects-1]-2),symsize=1,color=lcol[3],thick=3

oplot,D[0:ncollects-1]+1,(36-(inttime[2,0,0,0:ncollects-1]-2),symsize=1,color=lcol[4],psym=symbol[4],thick=3
oplot,D[0:ncollects-1]+1,(36-(inttime[2,0,0,0:ncollects-1]-2),symsize=1,color=lcol[4],thick=3

oplot,D[0:ncollects-1]+1,(15-(inttime[2,1,0,0:ncollects-1]-8),symsize=1,color=lcol[5],psym=symbol[5],thick=3
oplot,D[0:ncollects-1]+1,(15-(inttime[2,1,0,0:ncollects-1]-8),symsize=1,color=lcol[5],thick=3

XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,time_int,lcol,symbol

;*****************************************************************************
;  Plot dn versus integration time.
;*****************************************************************************

; Plot all detectors in a bands on one plot.
!p.multi=[0,1,1]
!p.position=0
        
title1='Integration Time versus dn'
FOR b=0, nbands-1 DO BEGIN
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            title2=band_name[b]+' '+HAM[ih]+' '+SS[is]

            ymax=max(dn[*,b,ih,0:detectors[b]-1,is,1,0],min=ymin)
        
            IF b EQ 0 THEN BEGIN
                plot,(15-(inttime[1,1,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,8,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[1,1,0,*])], $
                      xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata

                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,(15-(inttime[1,1,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(15-(inttime[1,1,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
            ENDFOR

            IF b EQ 1 THEN BEGIN
                plot,(15-(inttime[2,1,0,0:ncollects-1]-8))*2.2,dn[0:ncollects-1,b,ih,8,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[2,1,0,*])], $
                      xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata

                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,(15-(inttime[2,1,0,0:ncollects-1]-8))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(15-(inttime[2,1,0,0:ncollects-1]-8))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
            ENDFOR
            IF b EQ 2 OR b EQ 3 THEN BEGIN
                plot,(35-(inttime[1,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,8,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[1,0,0,*])], $
                      xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata

                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,(35-(inttime[1,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(35-(inttime[1,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
            ENDFOR
            IF b GE 4 THEN BEGIN
                plot,(36-(inttime[2,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,8,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[2,0,0,*])], $
                      xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata

                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,(36-(inttime[2,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(36-(inttime[2,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
            ENDFOR
            oplot,[-100,10000],[default[b],default[b]],symsize=1,color=lcol[1],linestyle=2,thick=3

            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF b LE 1 THEN set_legend,2,chname,lcol,symbol
            IF b GE 2 THEN set_legend,1,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

; Plot all detectors in a bands on separate plots.
!p.multi=[0,4,4]
!p.position=0
        
title1='Integration Time versus dn'
FOR b=0, nbands-1 DO BEGIN
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            FOR id=0, detectors[b]-1 DO BEGIN
                title2=band_name[b]+' '+HAM[ih]+' '+SS[is]+' '+DET[id]

                ymax=max(dn[*,b,ih,id,is,1,0],min=ymin)
        
                IF b EQ 0 THEN BEGIN
                    plot,(15-(inttime[1,1,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[1,1,0,*])], $
                          xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
                    
                    oplot,(15-(inttime[1,1,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(15-(inttime[1,1,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR

                IF b EQ 1 THEN BEGIN
                    plot,(15-(inttime[2,1,0,0:ncollects-1]-8))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[2,1,0,*])], $
                          xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
                    
                    oplot,(15-(inttime[2,1,0,0:ncollects-1]-8))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(15-(inttime[2,1,0,0:ncollects-1]-8))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
                IF b EQ 2 OR b EQ 3 THEN BEGIN
                    plot,(35-(inttime[1,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[1,0,0,*])], $
                          xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
                    
                    oplot,(35-(inttime[1,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(35-(inttime[1,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
                IF b GE 4 THEN BEGIN
                    plot,(36-(inttime[2,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],yrange=[ymin,ymax],xrange=[0,max(inttime[2,0,0,*])], $
                          xtit='Integration time (us)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
                    
                    oplot,(36-(inttime[2,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,(36-(inttime[2,0,0,0:ncollects-1]-2))*2.2,dn[0:ncollects-1,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[-100,10000],[default[b],default[b]],symsize=1,color=lcol[1],linestyle=2,thick=3

                XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
                IF b LE 1 THEN set_legend,2,chname,lcol,symbol
                IF b GE 2 THEN set_legend,1,chname,lcol,symbol
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

device,/close

END
